==> apache-fineract-1.7.2-src.tar.gz: apache-fineract-src-1.7.2/fineract-provider/src/test/java/org/apache/fineract/infrastructure/core/InstanceTypeStepDefinitions.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.fineract.infrastructure.core;

import io.cucumber.java8.En;
import org.apache.fineract.infrastructure.core.config.FineractProperties;
import org.springframework.beans.factory.annotation.Autowired;

public class InstanceTypeStepDefinitions implements En {

    @Autowired
    private FineractProperties fineractProperties;

    public InstanceTypeStepDefinitions() {
        Given("Set every Fineract instance type to false", () -> {
            fineractProperties.getMode().setWriteEnabled(false);
            fineractProperties.getMode().setReadEnabled(false);
            fineractProperties.getMode().setBatchEnabled(false);
        });
        Given("Fineract instance is a write instance", () -> {
            fineractProperties.getMode().setWriteEnabled(true);
        });
        Given("Fineract instance is a read instance", () -> {
            fineractProperties.getMode().setReadEnabled(true);
        });
        Given("Fineract instance is a batch instance", () -> {
            fineractProperties.getMode().setBatchEnabled(true);
        });
    }
}

==> apache-fineract-1.9.0-src.tar.gz: apache-fineract-src-1.9.0/fineract-provider/src/test/java/org/apache/fineract/infrastructure/core/InstanceTypeStepDefinitions.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.fineract.infrastructure.core;

import io.cucumber.java8.En;
import org.apache.fineract.infrastructure.core.config.FineractProperties;
import org.springframework.beans.factory.annotation.Autowired;

public class InstanceTypeStepDefinitions implements En {

    @Autowired
    private FineractProperties fineractProperties;

    public InstanceTypeStepDefinitions() {
        Given("Set every Fineract instance type to false", () -> {
            fineractProperties.getMode().setWriteEnabled(false);
            fineractProperties.getMode().setReadEnabled(false);
            fineractProperties.getMode().setBatchWorkerEnabled(false);
            fineractProperties.getMode().setBatchManagerEnabled(false);
        });
        Given("Fineract instance is a write instance", () -> {
            fineractProperties.getMode().setWriteEnabled(true);
        });
        Given("Fineract instance is a read instance", () -> {
            fineractProperties.getMode().setReadEnabled(true);
        });
        Given("Fineract instance is a batch manager instance", () -> {
            fineractProperties.getMode().setBatchManagerEnabled(true);
        });
    }
}
